summaryrefslogtreecommitdiffstats
path: root/src/cold-flash.c
diff options
context:
space:
mode:
authorAaro Koskinen <aaro.koskinen@iki.fi>2013-02-18 00:52:24 +0200
committerPali Rohár <pali.rohar@gmail.com>2013-02-18 00:18:44 +0100
commitf5a9d273ce7c57519de406b1a84dc71fc12674e6 (patch)
tree0dcfc591c82c3c7dba1911bd63c25b73050ed2f9 /src/cold-flash.c
parent22f71b0f255bcae680c98e1e174830a028dab1de (diff)
download0xFFFF-f5a9d273ce7c57519de406b1a84dc71fc12674e6.tar.bz2
cold-flash: correct chip/soc name
RX-51/N900 has OMAP3430, and it seems this is what the ASIC ID field at offset 4 refers to. Fix the comment and printf.
Diffstat (limited to 'src/cold-flash.c')
-rw-r--r--src/cold-flash.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cold-flash.c b/src/cold-flash.c
index 7b5d1fb..9467832 100644
--- a/src/cold-flash.c
+++ b/src/cold-flash.c
@@ -346,7 +346,7 @@ int init_cold_flash(struct usb_device_info * dev) {
if ( memcmp(asic_buffer+1, "\x01\x05\x01", 3) != 0 )
ERROR_RETURN("Invalid ASIC ID", -1);
/* ID Subblock - OMAP chip version (check for OMAP35x) */
if ( memcmp(asic_buffer+4, "\x34\x30\x07", 3) != 0 )
ERROR_RETURN("Invalid ASIC ID", -1);
@@ -366,7 +366,7 @@ int init_cold_flash(struct usb_device_info * dev) {
if ( memcmp(asic_buffer+58, "\x15\x09\x01", 3) != 0 )
ERROR_RETURN("Invalid ASIC ID", -1);
- printf("Detected OMAP35x chip\n");
+ printf("Detected OMAP3430 chip\n");
return 0;
@@ -346,7 +346,7 @@ int init_cold_flash(struct usb_device_info * dev) {
if ( memcmp(asic_buffer+1, "\x01\x05\x01", 3) != 0 )
ERROR_RETURN("Invalid ASIC ID", -1);
- /* ID Subblock - OMAP chip version (check for OMAP35x) */
+ /* ID Subblock - OMAP chip version (check for OMAP3430) */
if ( memcmp(asic_buffer+4, "\x34\x30\x07", 3) != 0 )
ERROR_RETURN("Invalid ASIC ID", -1);